Resources
=========

Additional resources related to the concept of map of elections or other objects.

Related Papers
~~~~~~~~~~~~~~

List of papers using mapof (from the most recent to the oldest).

- `A Map of Diverse Synthetic Stable Matching Instances <https://www.jair.org/index.php/jair/article/view/15213/27027>`_
- `Guide to Numerical Experiments on Elections in Computational Social Choice <https://www.ijcai.org/proceedings/2024/0881.pdf>`_
- `Discovering Consistent Subelections <https://www.ifaamas.org/Proceedings/aamas2024/pdfs/p935.pdf>`_
- `Participatory Budgeting: Data, Tools and Analysis <https://www.ijcai.org/proceedings/2023/0297.pdf>`_
- `An Experimental Comparison of Multiwinner Voting Rules on Approval Elections <https://www.ijcai.org/proceedings/2023/0298.pdf>`_
- `Diversity, Agreement, and Polarization in Elections <https://www.ijcai.org/proceedings/2023/0299.pdf>`_
- `Expected Frequency Matrices of Elections: Computation, Geometry, and Preference Learning <https://papers.nips.cc/paper_files/paper/2022/file/cb1a0e1bd8b2f20f7500c7886e1fbc60-Paper-Conference.pdf>`_
- `How to Sample Approval Elections? <https://www.ijcai.org/proceedings/2022/0071.pdf>`_
- `Understanding Distance Measures Among Elections <https://www.ijcai.org/proceedings/2022/0015.pdf>`_
- `Putting a Compass on the Map of Elections <https://www.ijcai.org/proceedings/2021/0009.pdf>`_
- `Drawing a Map of Elections in the Space of Statistical Cultures <https://www.ifaamas.org/Proceedings/aamas2020/pdfs/p1341.pdf>`_

Datasets & Examples
~~~~~~~~~~~~~~~~~~

In the `mapof-data repository <https://github.com/science-for-democracy/mapof-data>`_
you can find the datasets used in the papers above and some examples of how to use them.


Tutorial
~~~~~~~~

Recently, at AAAI, IJCAI, and AAMAS conferences a tutorial
related to conducting experiments with the use of map of elections was held.
The slides from these tutorials are available
`HERE <https://home.agh.edu.pl/~pragma/tutorials/aaai24/aaai-2024-tutorial.pdf>`_
